#!/bin/bash

# 配置
UPDATE_URL="http://example.com/updates/update_v1.0.1.tar.gz"
UPDATE_FILE="update_v1.0.1.tar.gz"
BACKUP_DIR="/path/to/backup"
INSTALL_DIR="/path/to/install"
LOG_FILE="/path/to/log/upgrade.log"

# 日志记录函数
log_info() {
    echo "[INFO] $1" | tee -a $LOG_FILE
}

log_error() {
    echo "[ERROR] $1" | tee -a $LOG_FILE
}

# 检查是否以root用户运行
if [ "$EUID" -ne 0 ]; then
    log_error "请以root用户运行该脚本。"
    exit 1
fi

# 下载更新包
log_info "下载更新包..."
if curl -o $UPDATE_FILE $UPDATE_URL; then
    log_info "更新包下载成功。"
else
    log_error "更新包下载失败。"
    exit 1
fi

# 验证更新包（假设使用SHA256校验和）
log_info "验证更新包..."
EXPECTED_CHECKSUM="your_expected_checksum_here"
ACTUAL_CHECKSUM=$(sha256sum $UPDATE_FILE | awk '{ print $1 }')

if [ "$EXPECTED_CHECKSUM" == "$ACTUAL_CHECKSUM" ]; then
    log_info "更新包验证成功。"
else
    log_error "更新包验证失败。"
    exit 1
fi

# 备份当前安装
log_info "备份当前安装..."
if [ -d "$INSTALL_DIR" ]; then
    TIMESTAMP=$(date +"%Y%m%d_%H%M%S")
    BACKUP_PATH="$BACKUP_DIR/backup_$TIMESTAMP"
    if cp -r $INSTALL_DIR $BACKUP_PATH; then
        log_info "备份成功，备份路径：$BACKUP_PATH"
    else
        log_error "备份失败。"
        exit 1
    fi
else
    log_error "安装目录不存在：$INSTALL_DIR"
    exit 1
fi

# 解压更新包
log_info "解压更新包..."
if tar -xzf $UPDATE_FILE -C $INSTALL_DIR; then
    log_info "解压成功。"
else
    log_error "解压失败。"
    exit 1
fi

# 执行安装脚本（假设更新包中包含install.sh脚本）
log_info "执行安装脚本..."
if [ -f "$INSTALL_DIR/install.sh" ]; then
    if bash $INSTALL_DIR/install.sh; then
        log_info "安装成功。"
    else
        log_error "安装失败。"
        exit 1
    fi
else
    log_error "安装脚本不存在：$INSTALL_DIR/install.sh"
    exit 1
fi

# 清理
log_info "清理临时文件..."
rm -f $UPDATE_FILE

log_info "升级完成。"
exit 0
